@@ -31,28 +31,28 @@ async def present(
     disk_encryption_key: make_dataclass(
         "CustomerEncryptionKey",
         [
-            ("rawKey", str, field(default=None)),
-            ("rsaEncryptedKey", str, field(default=None)),
-            ("kmsKeyName", str, field(default=None)),
-            ("kmsKeyServiceAccount", str, field(default=None)),
+            ("raw_key", str, field(default=None)),
+            ("rsa_encrypted_key", str, field(default=None)),
+            ("kms_key_name", str, field(default=None)),
+            ("kms_key_service_account", str, field(default=None)),
         ],
     ) = None,
     source_image_encryption_key: make_dataclass(
         "CustomerEncryptionKey",
         [
-            ("rawKey", str, field(default=None)),
-            ("rsaEncryptedKey", str, field(default=None)),
-            ("kmsKeyName", str, field(default=None)),
-            ("kmsKeyServiceAccount", str, field(default=None)),
+            ("raw_key", str, field(default=None)),
+            ("rsa_encrypted_key", str, field(default=None)),
+            ("kms_key_name", str, field(default=None)),
+            ("kms_key_service_account", str, field(default=None)),
         ],
     ) = None,
     source_snapshot_encryption_key: make_dataclass(
         "CustomerEncryptionKey",
         [
-            ("rawKey", str, field(default=None)),
-            ("rsaEncryptedKey", str, field(default=None)),
-            ("kmsKeyName", str, field(default=None)),
-            ("kmsKeyServiceAccount", str, field(default=None)),
+            ("raw_key", str, field(default=None)),
+            ("rsa_encrypted_key", str, field(default=None)),
+            ("kms_key_name", str, field(default=None)),
+            ("kms_key_service_account", str, field(default=None)),
         ],
     ) = None,
     labels: Dict[str, str] = None,
@@ -68,7 +68,7 @@ async def present(
     params: make_dataclass(
         "DiskParams",
         [
-            ("resourceManagerTags", Dict[str, str], field(default=None)),
+            ("resource_manager_tags", Dict[str, str], field(default=None)),
         ],
     ) = None,
     description: str = None,
@@ -173,7 +173,7 @@ async def present(
                         - SEV_SNP_CAPABLE
                     For more information, see Enabling guest operating system features.
 
-        disk_encryption_key(Dict[str, str], Optional):
+        disk_encryption_key(Dict[str, Any], Optional):
             Encrypts the disk using a customer-supplied encryption key or a customer-managed encryption key.
             Encryption keys do not protect access to metadata of the disk. After you encrypt a disk with a
             customer-supplied key, you must provide the same key if you use the disk later. For example,
@@ -187,16 +187,16 @@ async def present(
             automatically generated key and you don't need to provide a key to use the disk later.
             Defaults to None.
 
-                * rawKey(str, Optional)
+                * raw_key(str, Optional):
                     Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to either encrypt
                     or decrypt this resource. You can provide either the rawKey or the rsaEncryptedKey.
-                    For example: \"rawKey\": \"SGVsbG8gZnJvbSBHb29nbGUgQ2xvdWQgUGxhdGZvcm0=\"
+                    For example: \"raw_key\": \"SGVsbG8gZnJvbSBHb29nbGUgQ2xvdWQgUGxhdGZvcm0=\"
 
-                * rsaEncryptedKey(str, Optional)
+                * rsa_encrypted_key(str, Optional):
                     Specifies an RFC 4648 base64 encoded, RSA-wrapped 2048-bit customer-supplied encryption key to
                     either encrypt or decrypt this resource. You can provide either the rawKey or the rsaEncryptedKey.
                     For example:
-                        \"rsaEncryptedKey\":
+                        \"rsa_encrypted_key\":
                         \"ieCx/NcW06PcT7Ep1X6LUTc/hLvUDYyzSZPPVCVPTVEohpeHASqC8uw5TzyO9U+Fka9JFH z0mBibXUInrC/jEk014kCK/
                         NPjYgEMOyssZ4ZINPKxlUh2zn1bV+MCaTICrdmuSBTWlUUiFoD D6PYznLwh8ZNdaheCeZ8ewEXgFQ8V+sDroLaN3Xs3MDTXQEM
                         MoNUXMCZEIpg9Vtp9x2oe==\"
@@ -206,38 +206,38 @@ async def present(
                     Gets the RSA public key certificate provided by Google at:
                     https://cloud-certs.storage.googleapis.com/google-cloud-csek-ingress.pem
 
-                * kmsKeyName(str, Optional)
+                * kms_key_name(str, Optional):
                     The name of the encryption key that is stored in Google Cloud KMS.
                     For example:
-                        \"kmsKeyName\":
+                        \"kms_key_name\":
                         \"projects/kms_project_id/locations/region/keyRings/ key_region/cryptoKeys/key
 
-                * kmsKeyServiceAccount(str, Optional)
+                * kms_key_service_account(str, Optional):
                     The service account being used for the encryption request for the given KMS key. If absent,
                     the Compute Engine default service account is used. For example:
-                        \"kmsKeyServiceAccount\":
+                        \"kms_key_service_account\":
                         \"name@project_id.iam.gserviceaccount.com/
 
 
-        source_image_encryption_key(Dict[str, str], Optional):
+        source_image_encryption_key(Dict[str, Any], Optional):
             The customer-supplied encryption key of the source image.
             Required if the source image is protected by a customer-supplied encryption key.
             Defaults to None.
 
-                * rawKey(str, Optional)
-                * rsaEncryptedKey(str, Optional)
-                * kmsKeyName(str, Optional)
-                * kmsKeyServiceAccount(str, Optional)
+                * raw_key(str, Optional)
+                * rsa_encrypted_key(str, Optional)
+                * kms_key_name(str, Optional)
+                * kms_key_service_account(str, Optional)
 
-        source_snapshot_encryption_key(Dict[str, str], Optional):
+        source_snapshot_encryption_key(Dict[str, Any], Optional):
             The customer-supplied encryption key of the source snapshot.
             Required if the source snapshot is protected by a customer-supplied encryption key.
             Defaults to None.
 
-                * rawKey(str, Optional)
-                * rsaEncryptedKey(str, Optional)
-                * kmsKeyName(str, Optional)
-                * kmsKeyServiceAccount(str, Optional)
+                * raw_key(str, Optional)
+                * rsa_encrypted_key(str, Optional)
+                * kms_key_name(str, Optional)
+                * kms_key_service_account(str, Optional)
 
         labels(Dict[str, Dict[str, str]], Optional):
             Labels to apply to this disk. These can be later modified by the setLabels method.
@@ -303,13 +303,13 @@ async def present(
             but not persisted as part of resource payload.
             Defaults to None.
 
-                * resourceManagerTags(Dict[str, str], Optional)
+                * resourceManagerTags(Dict[str, str], Optional):
                     Resource manager tags to be bound to the disk. Tag keys and values have the same definition as
                     resource manager tags. Keys must be in the format `tagKeys/{tag_key_id}`, and values are in the format
                     `tagValues/456`. The field is ignored (both PUT & PATCH) when empty.
 
         description(str, Optional):
-            An optional description of this resource. Provide this property when you create the resource.
+            An optional description of this resource.
             Defaults to None.
 
     Returns:
