@@ -41,7 +41,7 @@ def resolve_sub(hub, ref: str, gcp_api):
         callpath = ref.split(".")
         resource_type = ".".join(callpath[1:-1])
         method_name = callpath[-1]
-        callpath[-2] = hub.tool.gcp.case.camel(callpath[-2])
+        callpath[0:-1] = [hub.tool.gcp.case.camel(v) for v in callpath[0:-1]]
 
         gcp_api_sub = gcp_api
         for c in callpath[1:]:
@@ -140,7 +140,9 @@ class ContractMod(LoadedMod):
 
         try:
             response = await self._gcp_method(ctx, *args, **raw_params)
-            if not response:
+            # Is it possible to get None for response. It looks like on error exceptions is thrown. If we are here
+            # then the call was successful.
+            if response is None:
                 result["result"] = False
                 return result
 
@@ -156,6 +158,12 @@ class ContractMod(LoadedMod):
                     items, self._resource_type
                 )
 
+            resource_type_camel = self._hub.tool.gcp.case.camel(
+                self._resource_type.split(".")[-1]
+            )
+            if resource_type_camel in response:
+                response["items"] = response[resource_type_camel]
+
             # TODO: Handle regional and global operations
 
             if response.get("nextPageToken"):
@@ -173,19 +181,25 @@ class ContractMod(LoadedMod):
                             items, self._resource_type
                         )
 
+                    resource_type_camel = self._hub.tool.gcp.case.camel(
+                        self._resource_type.split(".")[-1]
+                    )
+                    if resource_type_camel in response:
+                        response["items"] = response[resource_type_camel]
+
                     all_items += response.get("items", [])
                     raw_params["pageToken"] = response.get("nextPageToken")
 
                 response["items"] = all_items
 
             result["ret"] = self._hub.tool.gcp.resolver.process_response(
-                response, self._resource_type
+                response, self._resource_type, self._method_name
             )
         except Exception as e:
             if self._method_name == "get" and isinstance(e, NotFoundError):
                 result["comment"].append(
                     self._hub.tool.gcp.comment_utils.get_empty_comment(
-                        self._resource_type, name
+                        self._resource_type, name if name else resource_id
                     )
                 )
             else:
@@ -195,7 +209,7 @@ class ContractMod(LoadedMod):
         return result
 
 
-def process_response(hub, response: Dict, resource_type: str) -> Dict:
+def process_response(hub, response: Dict, resource_type: str, method_name: str) -> Dict:
     present_props_names = hub.tool.gcp.resource_prop_utils.get_present_properties(
         resource_type
     )
@@ -203,21 +217,26 @@ def process_response(hub, response: Dict, resource_type: str) -> Dict:
     # TODO: Get does not return all the necessary properties which should be the present properties so
     #  decide what to do
 
-    if isinstance(response.get("items"), list):
-        # Multiple entries in call result, e.g. after list() call
-        ret_items = []
-        for service_resource in response["items"]:
-            ret_items.append(
-                hub.tool.gcp.resolver.filter_raw_properties_to_present(
-                    service_resource, present_props_names, resource_type
-                )
-            )
-        return {"items": ret_items}
-    else:
-        # Single entry in call result, e.g. after get()/insert()/update() call
-        return hub.tool.gcp.resolver.filter_raw_properties_to_present(
+    singular_result_expected = hub.tool.gcp.resolver.has_singular_result(
+        response, resource_type, method_name
+    )
+    if singular_result_expected:
+        present_item = hub.tool.gcp.resolver.filter_raw_properties_to_present(
             response, present_props_names, resource_type
         )
+        # Single entry in call result, e.g. after get()/insert()/update() call
+        if present_item:
+            return present_item
+    else:
+        # Multiple entries in call result, e.g. after list() call
+        ret_items = []
+        for service_resource in response.get("items") or {}:
+            present_item = hub.tool.gcp.resolver.filter_raw_properties_to_present(
+                service_resource, present_props_names, resource_type
+            )
+            if present_item:
+                ret_items.append(present_item)
+        return {"items": ret_items}
 
 
 def filter_raw_properties_to_present(
@@ -226,6 +245,9 @@ def filter_raw_properties_to_present(
     resource_id = hub.tool.gcp.resource_prop_utils.extract_resource_id(
         raw_props, resource_type
     )
+    if not resource_id:
+        return None
+
     filtered = {
         key: value
         for key, value in raw_props.items()
@@ -255,3 +277,14 @@ def convert_dict_items_to_list(hub, dict_items: Dict, resource_type: str) -> lis
             list_items.append(service_resource)
 
     return list_items
+
+
+def has_singular_result(
+    hub, response: Dict, resource_type: str, method_name: str
+) -> bool:
+    # TODO: Figure out a better mechanism to determine whether a given method is expected to return a single entity
+    if isinstance(response.get("items"), list):
+        return False
+    if method_name in {"list", "aggregatedList", "describe"}:
+        return False
+    return True
