@@ -134,28 +134,16 @@ def get_exclude_keys_from_transformation(
 
 
 def extract_resource_id(hub, input_props: Dict, resource_type: str) -> Dict:
-    # TODO: check that GET, UPDATE, DELETE methods all get the same path params
-    # resource_id_path = hub.tool.gcp.resource_prop_utils.get_resource_path(resource_type)
+    if "selfLink" in input_props:
+        return hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
+            input_props.get("selfLink"), resource_type
+        )
 
-    # resource_id_prop_values = []
-    # for resource_id_prop in resource_id_path:
-    #     if resource_id_prop in input_props:
-    #         resource_id_prop_values.append(input_props[resource_id_prop])
-    #     #     TODO: handle this and other corner cases
-    #     # elif resource_id_prop == "resourceId" and "id" in input_props:
-    #     #     resource_id_prop_values.append(input_props["id"])
-    #     elif "name" in input_props:
-    #         resource_id_prop_values.append(input_props["name"])
-    #     elif "id" in input_props:
-    #         resource_id_prop_values.append(input_props["id"])
-    #     else:
-    #         raise "Unknown value for resource id element!"
-
-    # resource_id = resource_id_delimiter.join(resource_id_prop_values)
-
-    return hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
-        input_props.get("selfLink"), resource_type
-    )
+    if "resource_id" in hub.tool.gcp.RESOURCE_PROPS[resource_type]:
+        resource_id_fields = hub.tool.gcp.RESOURCE_PROPS[resource_type]["resource_id"]
+        for resource_id_field in resource_id_fields:
+            if resource_id_field in input_props:
+                return input_props[resource_id_field]
 
 
 def get_resource_path(hub, resource_type: str) -> List:
@@ -216,22 +204,23 @@ def get_elements_from_resource_id(hub, resource_type: str, resource_id: str) ->
 
 
 def parse_link_to_resource_id(hub, link, resource_type: str):
-    result = hub.tool.gcp.resource_prop_utils.get_resource_path(resource_type)
+    resource_path = hub.tool.gcp.resource_prop_utils.get_resource_path(resource_type)
+    result = copy.deepcopy(resource_path)
     src = result.split("/")
     act = link.split("/")
 
     idx = -1
-    key = None
-    val = None
-
     for s in reversed(src):
+        val = act[idx]
         if s.startswith("{") and s.endswith("}"):
-            val = act[idx]
-            key = s
-
+            result = result.replace(s, val)
+        elif val != s:
+            hub.log.warning(
+                f"Resource selfLink differs from the actual path for resource type: {resource_type}"
+                f"\nselfLink: {link}, PATH: {resource_path}"
+            )
+            return None
         idx -= 1
-        if idx % 2 != 0:
-            result = result.replace(key, val)
 
     return result
 
